@@ -3,8 +3,8 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
- 'ALIGNOF_LONG': 8,
- 'ALIGNOF_SIZE_T': 8,
+ 'ALIGNOF_LONG': 4,
+ 'ALIGNOF_SIZE_T': 4,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': '/usr/bin/ar',
@@ -18,17 +18,17 @@ build_time_vars = {'ABIFLAGS': '',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'x86_64-unknown-openbsd7.2',
+ 'BUILD_GNU_TYPE': 'i386-unknown-openbsd7.2',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG -O2 '
-           '-pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g',
+           '-pipe   -fPIC -O2 -pipe -O2 -pipe',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -pipe -g',
+ 'CONFIGURE_CFLAGS': '-O2 -pipe',
  'CONFIGURE_CFLAGS_NODIST': '-flto -g -std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -48,13 +48,13 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--sysconfdir=/etc' '--mandir=/usr/local/man' "
                 "'--infodir=/usr/local/info' '--localstatedir=/var' "
                 "'--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' "
-                "'CFLAGS=-O2 -pipe -g' 'LDFLAGS=-L/usr/local/lib/' "
+                "'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' "
                 "'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-3.10.7/Python-3.10.7/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.10.7/Python-3.10.7/lcov-report',
+ 'COVERAGE_INFO': '/build/tmp/pobj/Python-3.10.8/Python-3.10.8/coverage.info',
+ 'COVERAGE_REPORT': '/build/tmp/pobj/Python-3.10.8/Python-3.10.8/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
@@ -217,9 +217,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
- 'HAVE_GCC_ASM_FOR_X64': 1,
+ 'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 1,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -270,7 +270,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -528,17 +528,17 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'x86_64-unknown-openbsd7.2',
+ 'HOST_GNU_TYPE': 'i386-unknown-openbsd7.2',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.10 '
                    '/usr/local/include/python3.10',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.10',
- 'INSTALL': '/usr/obj/ports/Python-3.10.7/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-3.10.7/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.10.7/bin/install -c  -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.10.7/bin/install -c -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-3.10.7/bin/install -c -m 755',
+ 'INSTALL': '/build/tmp/pobj//Python-3.10.8/bin/install -c',
+ 'INSTALL_DATA': '/build/tmp/pobj//Python-3.10.8/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/build/tmp/pobj//Python-3.10.8/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/build/tmp/pobj//Python-3.10.8/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/build/tmp/pobj//Python-3.10.8/bin/install -c -m 755',
  'INSTSONAME': 'libpython3.10.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
@@ -612,7 +612,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG -O2 -pipe -g  -fPIC',
+ 'OPT': '-DNDEBUG -O2 -pipe   -fPIC',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -647,9 +647,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                             '-Wunreachable-code -DNDEBUG -O2 -pipe -g  -fPIC '
-                             '-O2 -pipe -g -O2 -pipe -g -flto -g -std=c99 '
-                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                             '-Wunreachable-code -DNDEBUG -O2 -pipe   -fPIC '
+                             '-O2 -pipe -O2 -pipe -flto -g -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
@@ -659,7 +659,7 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I/usr/local/include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG '
-              '-O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g',
+              '-O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
  'PY_CFLAGS_NODIST': '-flto -g -std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
@@ -668,27 +668,27 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fprofile-instr-use=code.profclangd -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
-                   '-DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g '
-                   '-flto -g -std=c99 -Wextra -Wno-unused-result '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden -I/usr/local/include '
-                   '-fprofile-instr-use=code.profclangd -I./Include/internal '
-                   '-I. -I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
+                   '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto -g '
+                   '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden '
+                   '-I/usr/local/include -fprofile-instr-use=code.profclangd '
+                   '-I./Include/internal -I. -I./Include -I/usr/local/include '
+                   '-fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/local/lib/ -flto -g '
-                    '-L/usr/obj/ports/Python-3.10.7/Python-3.10.7 '
+                    '-L/build/tmp/pobj//Python-3.10.8/Python-3.10.8 '
                     '-L/usr/local/lib/',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/usr/local/lib/',
- 'PY_LDFLAGS_NODIST': '-flto -g -L/usr/obj/ports/Python-3.10.7/Python-3.10.7 '
+ 'PY_LDFLAGS_NODIST': '-flto -g -L/build/tmp/pobj//Python-3.10.8/Python-3.10.8 '
                       '-L/usr/local/lib/',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
-                        '-DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe '
-                        '-g -flto -g -std=c99 -Wextra -Wno-unused-result '
+                        '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto '
+                        '-g -std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
@@ -704,7 +704,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.10.7/Python-3.10.7',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.10.8/Python-3.10.8',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -717,18 +717,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 16,
+ 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG_DOUBLE': 12,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-310',
@@ -747,10 +747,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '-L/usr/X11R6/lib -ltcl86 -ltk86',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.10.7/Python-3.10.7 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.10.8/Python-3.10.8 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.10.7/Python-3.10.7 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.10.8/Python-3.10.8 '
                './python ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -776,10 +776,10 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 0,
+ 'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-3.10.7/Python-3.10.7',
- 'abs_srcdir': '/usr/obj/ports/Python-3.10.7/Python-3.10.7',
+ 'abs_builddir': '/build/tmp/pobj/Python-3.10.8/Python-3.10.8',
+ 'abs_srcdir': '/build/tmp/pobj/Python-3.10.8/Python-3.10.8',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
